@@ -21,7 +21,7 @@ class BankAccountModelMixin(models.Model):
 
     bank_account_number = models.CharField(
         verbose_name=_('bank account number'),
-        help_text=_('Please provide bank account number as a form of xxxxxxxx-xxxxxxxx-xxxxxxxx'),
+        help_text=_('Please provide bank account number.'),
         max_length=24
     )
 
@@ -37,15 +37,33 @@ class MasterDataModel(models.Model):
         help_text=_('prime number is unique code for any master data')
     )
 
+    code = models.CharField(
+        verbose_name=_('code'),
+        max_length=100,
+        blank=True,
+        null=True,
+        default='',
+        help_text=_('Law-abiding master data code'),
+    )
+
     name = models.CharField(
         verbose_name=_('name'),
-        max_length=100,
+        max_length=1000,
         blank=False,
         null=False,
         default=None,
         help_text=_('Humanized name of master data'),
     )
 
+    description = models.CharField(
+        verbose_name=_('description'),
+        max_length=10000,
+        blank=True,
+        null=True,
+        default=None,
+        help_text=_('Long description'),
+    )
+
     def __str__(self) -> str:
         return self.name
 
@@ -176,11 +194,15 @@ class NationalityModelMixin(models.Model):
 
 class SubAccount(BankAccountModelMixin):
 
+
     class Meta:
         verbose_name = _('sub account')
 
 
 class DependenceQualityModel(MasterDataModel):
+    """
+    Eltartott minőség törzs
+    """
 
     class Meta:
         abstract = False
@@ -188,12 +210,24 @@ class DependenceQualityModel(MasterDataModel):
         verbose_name_plural = _('dependence qualities')
 
 class DependenceLegitimacyModel(MasterDataModel):
+    """
+    Eltartott jogosultság jogcím törzs
+    """
 
     class Meta:
         abstract = False
         verbose_name = _('dependence legitimacy')
         verbose_name_plural = _('dependence legitimacies')
 
+class IndependentActivityDeclarationCostModel(MasterDataModel):
+    """
+    Önálló tev. nyilatkozat költség törzs
+    """
+
+    class Meta:
+        verbose_name = _('independent-actvitiy declaration cost')
+        verbose_name_plural = _('independent-actvitiy declaration costs')
+
 class LegalTypeModel(MasterDataModel):
     pass
 
@@ -281,7 +315,7 @@ class PersonModel(PersonBirthDataMixin, PersonRegistratNameMixin, NationalityMod
         max_length=10,
         default=None,
         blank=True,
-        null=True
+        null=True,
     )
 
     permanent_address = AddressField(
@@ -318,6 +352,12 @@ class PersonModel(PersonBirthDataMixin, PersonRegistratNameMixin, NationalityMod
     def __str__(self):
         return str(self.full_name)
 
+class EnvironmentalClassificationModel(MasterDataModel):
+
+    class Meta:
+        verbose_name = _('Environmental Classification')
+        verbose_name_plural = _('Environmental Classifications')
+
 class BusinessFormModel(MasterDataModel):
 
     class Meta:
@@ -325,6 +365,48 @@ class BusinessFormModel(MasterDataModel):
         verbose_name_plural = _('business forms')
 
 
+class InsuranceSuspensionModel(MasterDataModel):
+
+    class Meta:
+        verbose_name = _('Insurance suspension')
+        verbose_name_plural = _('Insurance suspensions')
+
+class EmploymentQualityModel(MasterDataModel):
+
+    class Meta:
+        verbose_name = _('Employment quality')
+        verbose_name_plural = _('Employment qualities')
+
+class SmallBusinessTaxContributionDiscountModel(MasterDataModel):
+
+    class Meta:
+        verbose_name = _('small business tax contribution discount')
+        verbose_name_plural = _('small business tax contribution discounts')
+
+class SocialContributionDiscountModel(MasterDataModel):
+
+    class Meta:
+        verbose_name = _('Social contribution discount')
+        verbose_name_plural = _('Social contribution discounts')
+
+class PretenceModel(MasterDataModel):
+    """
+    Jogcím törzs
+    """
+
+    class Meta:
+        verbose_name = _('Pretence')
+        verbose_name_plural = _('Pretences')
+
+class LegalRelationshipModel(MasterDataModel):
+    """
+    Jogviszony törzs.
+    """
+
+    class Meta:
+        verbose_name = _('Legal relationship')
+        verbose_name_plural = _('Legal relationships')
+
 class OrganizationModel(MasterDataModel):
 
     class Meta:
